@@ -21,8 +21,11 @@ from rest_framework_jwt.compat import gettext_lazy as _
 from rest_framework_jwt.compat import has_set_cookie_samesite
 from rest_framework_jwt.settings import api_settings
 
+import re
+
 from sys import version_info
 
+
 @fixture
 def rsa_keys(scope="session"):
     from cryptography.hazmat.backends import default_backend
@@ -79,6 +82,43 @@ def test_valid_credentials_return_jwt(user, call_auth_endpoint):
     assert payload["username"] == user.get_username()
 
 
+def test_valid_credentials_return_jwt_uuid4_token_id(user, call_auth_endpoint):
+    response = call_auth_endpoint("username", "password")
+
+    token = response.json()["token"]
+    payload = JSONWebTokenAuthentication.jwt_decode_token(token)
+
+    pattern = r'[a-f0-9]{8}-[a-f0-9]{4}-4[a-f0-9]{3}-[89ab][a-f0-9]{3}-[a-f0-9]{12}\Z'
+    assert re.match(pattern, payload['jti'])
+
+
+def test_valid_credentials_return_jwt_without_token_id_when_configured_off(monkeypatch, user, call_auth_endpoint):
+    monkeypatch.setattr(api_settings, "JWT_TOKEN_ID", "off")
+    response = call_auth_endpoint("username", "password")
+
+    token = response.json()["token"]
+    payload = JSONWebTokenAuthentication.jwt_decode_token(token)
+
+    assert "jti" not in payload
+
+
+def test_valid_credentials_return_jwt_with_expected_claims(user, call_auth_endpoint):
+    response = call_auth_endpoint("username", "password")
+
+    token = response.json()["token"]
+    payload = JSONWebTokenAuthentication.jwt_decode_token(token)
+
+    expected_claims = {
+        'jti',
+        'username',
+        'iat',
+        'exp',
+        'user_id',
+        'orig_iat',
+    }
+    assert payload.keys() == expected_claims
+
+
 def test_valid_credentials_with_aud_and_iss_settings_return_jwt(
     monkeypatch, user, call_auth_endpoint
 ):
